@@ -69,8 +69,8 @@ class CardBase:
     tab_menu_type = 'tabs'
     default_empty_template = 'message'
 
-    def __init__(self, request, code, view=None, details_object=None, title=None,
-                 menu=None, tab_menu=None, template_name=None,
+    def __init__(self, request, code=None, view=None, details_object=None, title=None,
+                 menu=None, tab_menu=None, template_name=None, call_details_data=False,
                  group_type=CARD_TYPE_STANDARD, show_created_modified_dates=False,
                  footer=None, extra_card_context=None,
                  is_empty=False, empty_template_name=None, empty_message='N/A', **kwargs):
@@ -92,6 +92,7 @@ class CardBase:
         if isinstance(tab_menu, (list, tuple)):
             tab_menu = HtmlMenu(self.request, self.tab_menu_type).add_items(*tab_menu)
         self.tab_menu = tab_menu
+        self.call_details_data = call_details_data
 
         if is_empty:
             self.group_type = CARD_TYPE_STANDARD
@@ -382,6 +383,11 @@ class CardBase:
             getattr(self.view, setup_table_field)(details_object=self.details_object, table=table)
             if hasattr(self.view, 'tables'):
                 self.view.tables[self.code] = table
+        elif self.group_type == CARD_TYPE_STANDARD and self.call_details_data:
+            if self.code is not None and hasattr(self.view, f'get_{self.code}_data'):
+                getattr(self.view, f'get_{self.code}_data')(card=self, details_object=self.details_object)
+            elif hasattr(self.view, 'get_details_data'):
+                getattr(self.view, 'get_details_data')(card=self, details_object=self.details_object)
 
     def add_table(self, model, table_id=None):
         table = DatatableTable(table_id=table_id, model=model, view=self.view)
